package io.aalam.testapp;

import io.aalam.common.Callbacks;
import io.aalam.common.Permissions;
import io.aalam.common.router.Mapper;

class TestCallbacks implements Callbacks {
    public void routes(Mapper mapper) {
        /* We have the same handler for all the below urls. If not for submapper,
         * we will have to define 'handler' in each of the mapper.connect().
         */
        Mapper.SubMapper m = mapper.subMapper(new TestApp());

        try {
        /* Below url sends an index page. The static prefix will be
         * used inside the html page to access the static resources.
         * no permissions attribute means it can be accessed by anyone.
         */
        m.connect("/aalam/testapp/",
                  new String[]{"GET"},
                  "sendHomePage");

        /* Below url accepts input data, and it can be in xml/json format.
         * It allows only valid users with "Items/create" permission.
         */
        m.connect("/aalam/testapp/items",
                  new String[]{"PUT"},
                  "createItem",
                  Permissions.all("Items/create").deny_anon());

        /* Below URL will send a json output. We do not have a serializer
         * for this, because the framework will by default use the json
         * serializer for response data.
         * This api is denied for anonymous requests.
         */
        m.connect("/aalam/testapp/item/{item_name}",
                  new String[]{"GET"},
                  "getItem",
                  new Permissions().deny_anon());

        /* Below URL is used to update a setting, but will permit a user
         * to update the setting that is created by the same user.
         */
        m.connect("/aalam/testapp/item/{item_name}",
                  new String[]{"POST"},
                  "updateItem",
                  new Permissions().deny_anon());
        } catch (Exception e) {
            System.out.println(" -- Caught an exception while connecting a route");
            e.printStackTrace();
        }

    }

    /* Stub all the other methods in the Callbacks interface. */
    public void cleanup() {}
    public void migrate(String fromVersion) {}
    public void migrateCompleted() {}
}


public class TestEntry {
    public static Callbacks entryHandler(int state) {
        if (state != Callbacks.STATE_VALIDATION) {
            /* do the initialization here. */
        }

        /* entry point should return a Callbacks object. */
        return new TestCallbacks();
    }
}
